@@ -8,7 +8,7 @@ use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -41,7 +41,7 @@ sub register_prereqs
     {
       $self->zilla->register_prereqs(
         { phase => $_ },
-        'Alien::Build::MM' => '0.05',
+        'Alien::Build::MM' => '0.07',
         'ExtUtils::MakeMaker' => '6.52',
       ) for qw( configure build );
     }
@@ -153,7 +153,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -179,8 +179,13 @@ requires.
 
 =item adjusts Makefile.PL
 
-Adjusts your C<Makefile.Pl> to use L<Alien::Build::MM>.  In the future C<Build.PL>
-may be supported.
+Adjusts your C<Makefile.Pl> to use L<Alien::Build::MM>.  If you are using
+L<ExtUtils::MakeMaker>.
+
+=item sets the mb_class for Build.PL
+
+sets mb_class to L<Alien::Build::MB> on the L<Dist::Zilla::Plugin::ModuleBuild>
+plugin.  If you are using L<Module::Build>.
 
 =item turn on dynamic prereqs
 
@@ -190,7 +195,7 @@ Which are used by most L<Alien::Build> based L<Alien> distributions.
 
 =head1 SEE ALSO
 
-L<Alien::Build>, L<alienfile>, L<Alien::Base>, L<Alien::Build::MM>
+L<Alien::Build>, L<alienfile>, L<Alien::Base>, L<Alien::Build::MM>, L<Alien::Build::MB>
 
 =head1 AUTHOR
 
